# Mercury Engine Data Structures
Construct type definitions for Mercury Engine

| Format   | Samus Returns (Read) | Samus Returns (Write) | Dread (Read) | Dread (Write) |
| -------- | -------------------- | --------------------- | ------------ | ------------- |
| PAK      | &cross;              | &cross;               | &check;      | &check;       |
| BMSSD    | &cross;              | &cross;               | &check;      | &check;       |
| BRFLD    | &cross;              | &cross;               | &check;      | &check;       |
| BMSCC    | &cross;              | &cross;               | &check;      | &check;       |
| BRSA     | &cross;              | &cross;               | &check;      | &check;       |


## Example Usage

```python
# TODO
```
